Stan Math Library: Eigen::internal::significant_decimals_default_impl< stan::math::var, false > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
Eigen::internal::significant_decimals_default_impl< stan::math::var, false > Struct Template Reference

Implemented this for printing to stream. More...

`#include <Eigen_NumTraits.hpp>`

## Static Public Member Functions
static int | run ()

## Detailed Description

### template<>
struct Eigen::internal::significant_decimals_default_impl< stan::math::var, false >

Implemented this for printing to stream.

Definition at line 96 of file Eigen_NumTraits.hpp.

## Member Function Documentation

static int Eigen::internal::significant_decimals_default_impl< stan::math::var, false >::run | ( |  | ) |
| inlinestatic

Definition at line 97 of file Eigen_NumTraits.hpp.

The documentation for this struct was generated from the following file:

- stan/math/rev/mat/fun/Eigen_NumTraits.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.